They use-d PyFunceble!
======================

Just a list of tool/repository/code/infrastructure which uses or used
PyFunceble!

* `.pl-host-file`_
* `add.2o7Net`_
* `add.Dead`_
* `add.Risk`_
* `add.Spam`_
* `adfilt`_
* `Asads-Hosts`_
* `Badd-Boyz-Hosts`_
* `Badger Sett`_
* `blacklist`_
* `CoinBlockerLists`_
* `cookies_filters`_
* `DNS test`_
* `Facebook Zero Hosts Block`_
* `finnish-easylist-addition`_
* `Frellwits-filter-lists`_
* `Google AdService and ID.Google tracking hosts`_
* `KADhosts`_
* `MobileAdTrackers`_
* `My Privacy DNS`_
* `Phishing-URL-Testing-Database-of-Link-Statuses`_
* `Phishing.Database`_
* `polish-adblock-filters`_
* `polish-pihole-filters`_
* `pornhosts`_
* `Stop.Google.Analytics.Ghost.Spam.HOWTO`_
* `The-Big-List-of-Hacked-Malware-Web-Sites`_
* `Top-Attacking-IP-Addresses-Against-Wordpress-Sites`_
* `Ultimate.Hosts.Blacklist`_ // `Ultimate-Hosts-Blacklist`_
* `UncheckyAds`_

.. _.pl-host-file : https://github.com/xxcriticxx/.pl-host-file
.. _add.2o7Net : https://github.com/FadeMind/hosts.extras/tree/master/add.2o7Net
.. _add.Dead : https://github.com/FadeMind/hosts.extras/tree/master/add.Dead
.. _add.Risk : https://github.com/FadeMind/hosts.extras/tree/master/add.Risk
.. _add.Spam : https://github.com/FadeMind/hosts.extras/tree/master/add.Spam
.. _adfilt : https://github.com/DandelionSprout/adfilt
.. _Asads-Hosts : https://github.com/asaddon/Asads-Hosts
.. _Badd-Boyz-Hosts : https://github.com/mitchellkrogza/Badd-Boyz-Hosts
.. _Badger Sett : https://github.com/EFForg/badger-sett
.. _Blacklist : https://github.com/anudeepND/blacklist
.. _CoinBlockerLists : https://gitlab.com/ZeroDot1/CoinBlockerLists
.. _cookies_filters : https://github.com/MajkiIT/polish-ads-filter/blob/master/cookies_filters/adblock_cookies.txt
.. _DNS test : https://github.com/dns-test
.. _Facebook Zero Hosts Block : https://github.com/kowith337/PersonalFilterListCollection/blob/master/hosts/hosts_facebook0.txt
.. _finnish-easylist-addition : https://github.com/finnish-easylist-addition/finnish-easylist-addition
.. _Frellwits-filter-lists : https://github.com/lassekongo83/Frellwits-filter-lists
.. _Google AdService and ID.Google tracking hosts : https://github.com/kowith337/PersonalFilterListCollection/blob/master/hosts/hosts_google_adservice_id.txt
.. _KADhosts : https://github.com/azet12/KADhosts
.. _MobileAdTrackers : https://github.com/jawz101/MobileAdTrackers
.. _My Privacy DNS : https://www.mypdns.org
.. _Phishing-URL-Testing-Database-of-Link-Statuses : https://github.com/mitchellkrogza/Phishing-URL-Testing-Database-of-Link-Statuses
.. _Phishing.Database : https://github.com/mitchellkrogza/Phishing.Database
.. _polish-adblock-filters : https://github.com/MajkiIT/polish-ads-filter/blob/master/polish-adblock-filters/adblock.txt
.. _polish-pihole-filters : https://github.com/MajkiIT/polish-ads-filter/blob/master/polish-pihole-filters/hostfile.txt
.. _pornhosts : https://github.com/Import-External-Sources/pornhosts
.. _Stop.Google.Analytics.Ghost.Spam.HOWTO : https://github.com/mitchellkrogza/Stop.Google.Analytics.Ghost.Spam.HOWTO
.. _The-Big-List-of-Hacked-Malware-Web-Sites : https://github.com/mitchellkrogza/The-Big-List-of-Hacked-Malware-Web-Sites
.. _Top-Attacking-IP-Addresses-Against-Wordpress-Sites : https://github.com/mitchellkrogza/Top-Attacking-IP-Addresses-Against-Wordpress-Sites
.. _Ultimate.Hosts.Blacklist : https://github.com/mitchellkrogza/Ultimate.Hosts.Blacklist
.. _Ultimate-Hosts-Blacklist : https://github.com/Ultimate-Hosts-Blacklist
.. _UncheckyAds : https://github.com/FadeMind/hosts.extras/tree/master/UncheckyAds
